=====================
Ironic tempest plugin
=====================

This directory contains Tempest tests to cover the ironic and ironic-inspector
projects, as well as a plugin to automatically load these tests into tempest.

See the tempest plugin documentation for information about creating
a plugin, stable API interface, TempestPlugin class interface, plugin
structure, and how to use plugins:
https://docs.openstack.org/tempest/latest/plugin.html

See the Ironic documentation for information about how to run the
tempest tests:
https://docs.openstack.org/ironic/latest/contributor/dev-quickstart.html#running-tempest-tests
